"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheMock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
const NodeCache = require("node-cache");
/**
 * Cache Mock class
 */
class CacheMock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks a Delete response
         */
        this.Delete = 1;
        /**
         * Mocks a Get response
         */
        this.Get = { 'key': 'value' };
        /**
         * Mocks a Set response
         */
        this.Set = true;
    }
    /**
     * Create the APIGateway mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`Cache Error`);
        // implement the responses
        const responses = {
            // delete response
            del: {
                response: () => {
                    return returnError ?
                        rejectResponse :
                        this.Delete;
                }
            },
            // flush response
            flushAll: {
                response: () => {
                    return returnError ?
                        rejectResponse :
                        undefined;
                }
            },
            // get response
            get: {
                response: () => {
                    return returnError ?
                        rejectResponse :
                        this.Get;
                }
            },
            // set response
            set: this.Set,
        };
        // create the functions
        let functions = new NodeCache();
        functions = {
            del: () => this.Delete,
            flushAll: () => responses.flushAll,
            get: () => responses.get,
            set: () => responses.set,
        };
        return functions;
    }
}
exports.CacheMock = CacheMock;
//# sourceMappingURL=mock.js.map